<?php

namespace Hrm\Jobrole\Policies;

use Litepie\User\Contracts\UserPolicy;
use Hrm\Jobrole\Models\JobRole;

class JobRolePolicy
{

    /**
     * Determine if the given user can view the job_role.
     *
     * @param UserPolicy $user
     * @param JobRole $job_role
     *
     * @return bool
     */
    public function view(UserPolicy $user, JobRole $job_role)
    {
        if ($user->canDo('jobrole.job_role.view') && $user->isAdmin()) {
            return true;
        }

        return $job_role->user_id == user_id() && $job_role->user_type == user_type();
    }

    /**
     * Determine if the given user can create a job_role.
     *
     * @param UserPolicy $user
     * @param JobRole $job_role
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('jobrole.job_role.create');
    }

    /**
     * Determine if the given user can update the given job_role.
     *
     * @param UserPolicy $user
     * @param JobRole $job_role
     *
     * @return bool
     */
    public function update(UserPolicy $user, JobRole $job_role)
    {
        if ($user->canDo('jobrole.job_role.edit') && $user->isAdmin()) {
            return true;
        }

        return $job_role->user_id == user_id() && $job_role->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given job_role.
     *
     * @param UserPolicy $user
     * @param JobRole $job_role
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, JobRole $job_role)
    {
        return $job_role->user_id == user_id() && $job_role->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given job_role.
     *
     * @param UserPolicy $user
     * @param JobRole $job_role
     *
     * @return bool
     */
    public function verify(UserPolicy $user, JobRole $job_role)
    {
        if ($user->canDo('jobrole.job_role.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given job_role.
     *
     * @param UserPolicy $user
     * @param JobRole $job_role
     *
     * @return bool
     */
    public function approve(UserPolicy $user, JobRole $job_role)
    {
        if ($user->canDo('jobrole.job_role.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
