<?php

namespace Hrm\Jobrole\Providers;

use Illuminate\Support\ServiceProvider;

class JobroleServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'jobrole');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'jobrole');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerJobrole();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerJobrole()
    {
        $this->app->bind('jobrole', function($app) {
            return new Jobrole($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Jobrole', 'Lavalite\Jobrole\Facades\Jobrole');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('hrm.jobrole', function ($app) {
            return $this->app->make('Hrm\Jobrole\Jobrole');
        });

                // Bind JobRole to repository
        $this->app->bind(
            'Hrm\Jobrole\Interfaces\JobRoleRepositoryInterface',
            \Hrm\Jobrole\Repositories\Eloquent\JobRoleRepository::class
        );

        $this->app->register(\Hrm\Jobrole\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Hrm\Jobrole\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and jobrole's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/jobrole.php', 'jobrole'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeJobrole::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['hrm.jobrole'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('hrm/jobrole.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/jobrole')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/jobrole')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
